@@ -12,7 +12,7 @@ import pytz
 _logger = logging.getLogger(__name__)
 
 TZ = pytz.timezone("Australia/Sydney")
-ATTRIBUTION = "Health Protection NSW https://www.health.nsw.gov.au/Infectious/covid-19/Pages/stats-nsw.aspx#"
+ATTRIBUTION = "© State of New South Wales NSW Ministry of Health. For current information go to www.health.nsw.gov.au"
 DATA_SOURCES = {
     "published": {
         "host": None,
@@ -426,7 +426,6 @@ class StatisticHandler(object):
             and get["soup"] is not None
         ):
             reference = get["soup"].select_one(statistic.selector)
-            _logger.debug("%s :: %s", statistic.selector, reference)
 
             if not reference:
                 return statistic
@@ -442,7 +441,6 @@ class StatisticHandler(object):
             and get["dom"] is not None
         ):
             reference = get["dom"].xpath(statistic.xpath)
-            _logger.debug("%s :: %s", statistic.xpath, reference)
 
             if not reference and reference[0]:
                 return statistic
@@ -579,17 +577,22 @@ class Statistic(object):
         if self.changed and event_receiver is not None:
             try:
                 event_receiver(
-                    event_type="statistic",
-                    statistic_id=self.__id,
+                    event_type="statistic_updated",
+                    statistic_id=self.id,
                     statistic=self,
                     ts=self.updated,
                 )
                 _logger.debug(
-                    "Change sent to event handler for %s (%d)",
+                    "Change sent to event handler for %s (%s)",
                     self.name,
                     self.id,
                 )
             except Exception as err:
+                _logger.error(
+                    "Failed to send event to event receiver %s (%s)",
+                    self.name,
+                    self.id,
+                )
                 _logger.exception(err)
 
     @property
@@ -658,6 +661,13 @@ class Statistic(object):
         except AttributeError:
             return None
 
+    @property
+    def published(self):
+        try:
+            return self.__handler.statistics["published"].status
+        except AttributeError:
+            return None
+
     @property
     def typeName(self):
         try:
